#
# spec file for package isl
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define islsover 23
Name:           isl
Version:        0.27
Release:        1.1
Summary:        Integer Set Library
License:        MIT
Group:          Development/Languages/C and C++
URL:            https://libisl.sourceforge.io/
Source:         https://libisl.sourceforge.io/isl-%{version}.tar.xz
Source1:        baselibs.conf
BuildRequires:  gmp-devel
BuildRequires:  pkgconfig

%description
ISL is a library for manipulating sets and relations of integer points
bounded by linear constraints.
It is used by Cloog and the GCC Graphite optimization framework.

%package devel
Summary:        Development tools for ISL
Group:          Development/Languages/C and C++
Requires:       libisl%{islsover} = %{version}-%{release}

%description devel
Development tools and headers for the ISL.

%package -n libisl%{islsover}
Summary:        The ISL shared library
Group:          System/Libraries

%description -n libisl%{islsover}
The shared library for the ISL.

ISL is a library for manipulating sets and relations of integer points
bounded by linear constraints.

%prep
%setup -q

%build
export CFLAGS_FOR_BUILD="%{optflags}"
%configure --disable-static
%make_build

%check
%make_build check

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
rm -f  %{buildroot}%{_libdir}/libisl.so.*-gdb.py

%post -n libisl%{islsover} -p /sbin/ldconfig
%postun -n libisl%{islsover} -p /sbin/ldconfig

%files -n libisl%{islsover}
%{_libdir}/libisl.so.%{islsover}*

%files devel
%{_includedir}/isl
%{_libdir}/libisl.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Mon Feb 10 2025 Dirk Müller <dmueller@suse.com>
- update to 0.27:
  * improved modulo detection
  * remove all unused local variables from affine expressions
  * minor improvements to coalescing
  * minor improvements to lexicographic optimization
  * improved constraint simplification
  * fix handling of empty piecewise expressions
* Mon Apr  3 2023 Dirk Müller <dmueller@suse.com>
- update to 0.26:
  * fix inherited overloaded methods in Python bindings
  * decompose topological sort of clusters in incremental
    scheduler
  * improved isl_pw_aff_list_{min,max}
  * add some convenience functions
  * more exports to (templated C++) bindings
  * slightly improved conversion from binary relation to function
* Mon Jul 18 2022 Dirk Müller <dmueller@suse.com>
- update to 0.25:
  * support (type safe) user object on id in bindings
  * more exports to (templated C++) bindings
  * add some convenience functions
* Sun May  9 2021 Dirk Müller <dmueller@suse.com>
- update to 0.24:
  - improved (C++) bindings (inherit methods, renamed exports)
  - initial templated C++ bindings
  - detect bounds on constant polynomials as tight
* Mon Jan 25 2021 Andreas Schwab <schwab@suse.de>
- Compile with %%optflags
* Tue Dec 29 2020 Dirk Müller <dmueller@suse.com>
- update to 0.23:
  - minor improvements to coalescing
  - use build compiler to build extract_interface
  - add some convenience functions
  - ignore parameters in isl_union_* hash tables
* Thu Feb  6 2020 Martin Liška <mliska@suse.cz>
- Update to 0.22.1:
  - fix error handling
- Remove isl_basic_map_underlying_set-fix.patch with is part
  of the release.
* Fri Jan 10 2020 Martin Liška <mliska@suse.cz>
- Add isl_basic_map_underlying_set-fix.patch from upstream.
* Fri Jan  3 2020 Martin Liška <mliska@suse.cz>
- Update to 0.22:
  * improved bindings
  * scheduler fix involving fixed dimensions
  * accept ranges in tuples during parsing
  * add some convenience functions
- Update to 0.21:
  * preliminary C++ bindings
  * use incremental scheduler by default
  * introduce isl_size type
  * rename isl_ast_op_type to isl_ast_expr_op_type
  * fix coalescing bugs
  * use isl_bool to return extra boolean argument
* Thu Aug  9 2018 rpm@fthiessen.de
- Update to 0.20
  * keep track of domain in 0D isl_multi_pw_aff and
    isl_multi_union_pw_aff
  * add isl_aff_eval and isl_pw_aff_eval
  * add fixed-size rectangular box hull
* Wed Mar  7 2018 rguenther@suse.com
- Update to 0.19
  * minor improvements to coalescing
  * minor improvement to parametric integer programming
  * try harder to avoid large coefficients in scheduler
  * support kill accesses in dependence analysis
  * drop deprecated isl_int
  * drop deprecated band forests
  * drop deprecated functions
* Wed Jan 31 2018 jengelh@inai.de
- Set shared library RPM group. Use %%make_install.
* Mon Jan 29 2018 msrb@suse.com
- Include pkgconfig files in isl-devel package.
- Do not build static libraries (instead of deleting them after).
* Tue Jan 31 2017 rguenther@suse.com
- Update to 0.18
  * improve elimination of redundant existentially quantified variables
  * improve coalescing
  * improve parametric integer programming
  * preserve isolate option in isl_schedule_node_band_split
  * print AST nodes in YAML format
  * minor improvements to Python bindings
- Inherits update to 0.17.1
  * fix bug in coalescing treatment
- Inherits update to 0.17
  * optionally combine SCCs incrementally in scheduler
  * optionally maximize coincidence in scheduler
  * optionally avoid loop coalescing in scheduler
  * fix handling of nested integer divisions
  * optionally detect min/max expressions during AST generation
  * minor AST generator improvements
  * simplify stride constraints
  * improve support for expansions in schedule trees
* Sun Feb  7 2016 mpluskal@suse.com
- Update to 0.16.1
  * fix bug in simplification
- Changes for 0.16
  * add 32 bit integer optimization for IMath
  * minor AST generator improvements
  * add isl_union_flow_get_full_{may,must}_dependence
  * minor improvements to Python bindings
  * minor improvements to set and map printing
* Sun Jan 31 2016 mpluskal@suse.com
- Use url for source
- Cleanup spec file with spec-cleaner
- Make building more verbose
* Thu Dec  3 2015 rguenther@suse.com
- Update to ISL version 0.15
  * improve coalescing
  * add isl_union_access_info_compute_flow
  * add mark nodes in AST
  * add isl_union_pw_aff and isl_multi_union_pw_aff
  * add schedule trees
  * deprecate band forests
  * deprecate separation_class AST generation option
  * introduce isl_bool and isl_stat types
- Removes no longer needed isl-0.14-fixes.patch.
* Thu Dec  4 2014 rguenther@suse.com
- Update to ISL version 0.14
  * support IMath as an optional replacement for GMP
  * minor AST generator improvements
- Inherits changes from ISL version 0.13
  * deprecate isl_int
  * improved support for multi piecewise quasi-affine expressions
  * allow the user to impose a bound on the number of low-level operations
  * add isl_id_to_ast_expr and isl_id_to_pw_aff
  * add isl_schedule_constraints
  * hide internal structure of isl_vec
  * remove support for piplib
- Add isl-0.14-fixes.patch to fix function returning without value.
* Thu Feb 13 2014 rguenther@suse.com
- Update to ISL version 0.12.2
  * isl_int has been replaced by isl_val
  * some of the old functions are still available in isl/deprecated/*.h
  but they will be removed in the future
  * The functions isl_pw_qpolynomial_eval, isl_union_pw_qpolynomial_eval,
  isl_pw_qpolynomial_fold_eval and isl_union_pw_qpolynomial_fold_eval have
  been changed to return an isl_val instead of an isl_qpolynomial
- Remove obsolete config-guess-sub-update.diff patch
* Mon Jun 24 2013 rguenther@suse.com
- Update to ISL version 0.12
  * adds isl_val abstraction
* Thu Feb  7 2013 dmueller@suse.com
- Add config-guess-sub-update.diff:
  * Update config.guess/sub for aarch64
* Mon Dec 17 2012 rguenther@suse.com
- Update to ISL version 0.11.1
  * fixes endianess issue
  * now comes with a LICENSE file
* Tue Dec  4 2012 rguenther@suse.com
- Update to ISL version 0.11
  * license change to MIT
  * add support for code generation
* Thu Sep 27 2012 idonmez@suse.com
- Add baselibs.conf, needed by cloog-isl-32bit
* Thu Jun 21 2012 rguenther@suse.com
- ISL 0.10
